# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dig_ass_chat_protos/DigitalAssistantChatManager.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'dig_ass_chat_protos/DigitalAssistantChatManager.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5dig_ass_chat_protos/DigitalAssistantChatManager.proto\x12\x12\x64ig.ass.manager.v1\"\x95\x01\n\"DigitalAssistantChatManagerRequest\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12:\n\x0cOuterContext\x18\x02 \x01(\x0b\x32$.dig.ass.manager.v1.OuterContextItem\x12\x11\n\tRequestId\x18\x03 \x01(\t\x12\x12\n\nResourceId\x18\x04 \x01(\t\"f\n#DigitalAssistantChatManagerResponse\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\r\n\x05State\x18\x02 \x01(\t\x12\x0e\n\x06\x41\x63tion\x18\x03 \x01(\t\x12\x12\n\nResourceId\x18\x04 \x01(\t\"r\n\x10OuterContextItem\x12\x0b\n\x03Sex\x18\x01 \x01(\x08\x12\x0b\n\x03\x41ge\x18\x02 \x01(\r\x12\x0e\n\x06UserId\x18\x03 \x01(\t\x12\x11\n\tSessionId\x18\x04 \x01(\t\x12\x10\n\x08\x43lientId\x18\x05 \x01(\t\x12\x0f\n\x07TrackId\x18\x06 \x01(\t2\xa2\x01\n\x1b\x44igitalAssistantChatManager\x12\x82\x01\n\x0fGetChatResponse\x12\x36.dig.ass.manager.v1.DigitalAssistantChatManagerRequest\x1a\x37.dig.ass.manager.v1.DigitalAssistantChatManagerResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dig_ass_chat_protos.DigitalAssistantChatManager_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DIGITALASSISTANTCHATMANAGERREQUEST']._serialized_start=78
  _globals['_DIGITALASSISTANTCHATMANAGERREQUEST']._serialized_end=227
  _globals['_DIGITALASSISTANTCHATMANAGERRESPONSE']._serialized_start=229
  _globals['_DIGITALASSISTANTCHATMANAGERRESPONSE']._serialized_end=331
  _globals['_OUTERCONTEXTITEM']._serialized_start=333
  _globals['_OUTERCONTEXTITEM']._serialized_end=447
  _globals['_DIGITALASSISTANTCHATMANAGER']._serialized_start=450
  _globals['_DIGITALASSISTANTCHATMANAGER']._serialized_end=612
# @@protoc_insertion_point(module_scope)



from dig_ass_chat_protos.DigitalAssistantChatManager_pb2_grpc import (
    DigitalAssistantChatManagerStub,
)
from dig_ass_chat_protos.DigitalAssistantChatManager_pb2 import (
    DigitalAssistantChatManagerRequest,
    DigitalAssistantChatManagerResponse,
    OuterContextItem,
)
from typing import Any
from agi_med_protos.abstract_client import AbstractClient


class ChatManagerClient(AbstractClient):
    def __init__(self, address) -> None:
        super().__init__(address)
        self._stub = DigitalAssistantChatManagerStub(self._channel)

    def __call__(self, text: str, outer_context: dict, request_id: str, resource_id: str) -> str:
        request = DigitalAssistantChatManagerRequest(
            Text=text,
            OuterContext=OuterContextItem(
                Sex=outer_context["Sex"],
                Age=outer_context["Age"],
                UserId=outer_context["UserId"],
                SessionId=outer_context["SessionId"],
                ClientId=outer_context["ClientId"],
                TrackId=outer_context["TrackId"],
            ),
            RequestId=request_id,
            ResourceId=resource_id,
        )
        response: DigitalAssistantChatManagerResponse = self._stub.GetChatResponse(
            request
        )
        replica: dict[str, Any] = {
            "Text": response.Text,
            "ResourceId": response.ResourceId,
            "State": response.State,
            "Action": response.Action,
        }
        return replica



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DigitalAssistantChatManagerRequest(_message.Message):
    __slots__ = ("Text", "OuterContext", "RequestId", "ResourceId")
    TEXT_FIELD_NUMBER: _ClassVar[int]
    OUTERCONTEXT_FIELD_NUMBER: _ClassVar[int]
    REQUESTID_FIELD_NUMBER: _ClassVar[int]
    RESOURCEID_FIELD_NUMBER: _ClassVar[int]
    Text: str
    OuterContext: OuterContextItem
    RequestId: str
    ResourceId: str
    def __init__(self, Text: _Optional[str] = ..., OuterContext: _Optional[_Union[OuterContextItem, _Mapping]] = ..., RequestId: _Optional[str] = ..., ResourceId: _Optional[str] = ...) -> None: ...

class DigitalAssistantChatManagerResponse(_message.Message):
    __slots__ = ("Text", "State", "Action", "ResourceId")
    TEXT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    RESOURCEID_FIELD_NUMBER: _ClassVar[int]
    Text: str
    State: str
    Action: str
    ResourceId: str
    def __init__(self, Text: _Optional[str] = ..., State: _Optional[str] = ..., Action: _Optional[str] = ..., ResourceId: _Optional[str] = ...) -> None: ...

class OuterContextItem(_message.Message):
    __slots__ = ("Sex", "Age", "UserId", "SessionId", "ClientId", "TrackId")
    SEX_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    USERID_FIELD_NUMBER: _ClassVar[int]
    SESSIONID_FIELD_NUMBER: _ClassVar[int]
    CLIENTID_FIELD_NUMBER: _ClassVar[int]
    TRACKID_FIELD_NUMBER: _ClassVar[int]
    Sex: bool
    Age: int
    UserId: str
    SessionId: str
    ClientId: str
    TrackId: str
    def __init__(self, Sex: bool = ..., Age: _Optional[int] = ..., UserId: _Optional[str] = ..., SessionId: _Optional[str] = ..., ClientId: _Optional[str] = ..., TrackId: _Optional[str] = ...) -> None: ...
